@@ -37,7 +37,7 @@ use CallBackery::Plugin::Doc;
 use CallBackery::Database;
 use CallBackery::User;
 
-our $VERSION = '0.49.1';
+our $VERSION = '0.49.2';
 
 =head2 config
 
@@ -143,6 +143,9 @@ sub startup {
         }
     }
 
+    ## commands
+    unshift @{$app->commands->namespaces},  __PACKAGE__.'::Command';
+
     unshift @{$app->static->paths}, 
         $app->home->rel_file('frontend').'/compiled/source/'
         if $app->mode eq 'development';    # Router
